@@ -15,32 +15,67 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: dictionarycreationwizard.h 425225 2005-06-14 09:09:55Z ossi $
+// $Id: dictionarycreationwizard.h 779869 2008-02-27 08:28:05Z mlaurent $
 
 #ifndef DICTIONARYCREATIONWIZARD_H
 #define DICTIONARYCREATIONWIZARD_H
 
-#include <qptrlist.h>
-#include <qmap.h>
+#include <QtCore/QList>
+#include <QtCore/QMap>
+#include <Qt3Support/Q3Dict>
 
-#include <kwizard.h>
+#include <k3wizard.h>
 #include <knuminput.h>
-#include "kdedocsourceui.h"
 
-class CreationSourceUI;
+#include "ui_creationsourceui.h"
+#include "ui_creationsourcedetailsui.h"
+#include "ui_kdedocsourceui.h"
+
 class CompletionWizardWidget;
-class CreationSourceDetailsUI;
-class KDEDocSourceUI;
 class QTextCodec;
 class QComboBox;
 class MergeWidget;
 
+class CreationSourceDetailsWidget : public QWidget, public Ui::CreationSourceDetailsUI {
+   Q_OBJECT
+public:
+   CreationSourceDetailsWidget(QWidget *parent, const char *name)
+      : QWidget(parent) {
+      setupUi(this);
+      setObjectName(name);
+   }
+};
+
+class CreationSourceWidget : public QWidget, public Ui::CreationSourceUI {
+   Q_OBJECT
+public:
+   CreationSourceWidget(QWidget *parent, const char *name)
+      : QWidget(parent) {
+      setupUi(this);
+      setObjectName(name);
+   }
+};
+
+class KDEDocSourceWidget : public QWidget, public Ui::KDEDocSourceUI {
+   Q_OBJECT
+public:
+   KDEDocSourceWidget(QWidget *parent, const char *name)
+      : QWidget(parent) {
+      setupUi(this);
+      setObjectName(name);
+      languageButton->showLanguageCodes(true);
+      languageButton->loadAllLanguages();
+
+      ooDictURL->setFilter ("*.dic");
+   }
+};
+
 /**
  * This class represents a wizard that is used in order to gather all
  * necessary information for creating a new dictionary for the word
  * completion.
  */
-class DictionaryCreationWizard : public KWizard {
+class DictionaryCreationWizard : public K3Wizard {
    Q_OBJECT
 public:
    DictionaryCreationWizard (QWidget *parent, const char *name,
@@ -60,13 +95,13 @@ private:
    void buildCodecList ();
    void buildCodecCombo (QComboBox *combo);
 
-   CreationSourceUI *creationSource;
-   CreationSourceDetailsUI *fileWidget;
-   CreationSourceDetailsUI *dirWidget;
-   KDEDocSourceUI *kdeDocWidget;
+   CreationSourceWidget *creationSource;
+   CreationSourceDetailsWidget *fileWidget;
+   CreationSourceDetailsWidget *dirWidget;
+   KDEDocSourceWidget *kdeDocWidget;
    MergeWidget *mergeWidget;
 
-   QPtrList<QTextCodec> *codecList;
+   QList<QTextCodec*> *codecList;
 };
 
 /**
@@ -74,10 +109,10 @@ private:
  * KDE documentation.
  * @author Gunnar Schmi Dt
  */
-class MergeWidget : public QScrollView {
+class MergeWidget : public Q3ScrollView {
    Q_OBJECT
 public:
-   MergeWidget(KWizard *parent, const char *name,
+   MergeWidget(K3Wizard *parent, const char *name,
                QStringList dictionaryNames,
                QStringList dictionaryFiles,
                QStringList dictionaryLanguages);
@@ -87,8 +122,8 @@ public:
    QString language ();
 
 private:
-   QDict<QCheckBox> dictionaries;
-   QDict<KIntNumInput> weights;
+   Q3Dict<QCheckBox> dictionaries;
+   Q3Dict<KIntNumInput> weights;
    QMap<QString,QString> languages;
 };
 
@@ -97,11 +132,11 @@ private:
  * KDE documentation.
  * @author Gunnar Schmi Dt
  */
-class CompletionWizardWidget : public KDEDocSourceUI {
+class CompletionWizardWidget : public QWidget, public Ui::KDEDocSourceUI {
    Q_OBJECT
    friend class ConfigWizard;
 public:
-   CompletionWizardWidget(KWizard *parent, const char *name);
+   CompletionWizardWidget(K3Wizard *parent, const char *name);
    ~CompletionWizardWidget();
 
    void ok (KConfig *config);
