@@ -17,18 +17,16 @@
 using namespace std;
 
 // QT includes
-#include <qobject.h>
-#include <qwidget.h>
-#include <qframe.h>
+#include <QtCore/QObject>
+#include <QtGui/QWidget>
+#include <Qt3Support/Q3Frame>
 
+// KDE includes
 #include <kdemacros.h>
 #include "kdeexportfix.h"
 
-// KDE includes
-#include <kapplication.h>
-
 // App specific includes
-
+#include "ui_KTTSDlibSetup.h"
 
 namespace TTS {
     enum {AUDIOFILE=1};
@@ -41,6 +39,7 @@ namespace ACTIONS {
 
 // forward declarations
 class kttsdlibtalker2;
+class K3Process;
 
 /**
 @author Robert Vogl
@@ -106,6 +105,8 @@ public:
 
 private slots:
     void removeAllJobsFromList();  
+    void slotLaunchControlcenter();
+    void slotKCMProcessExited(K3Process *p);
     
 private:
     KApplication *m_Appl;
@@ -113,7 +114,7 @@ private:
     uint m_curJobNum;
     typedef queue<uint> jobListType;
     jobListType jobList;
-
+    Ui::KTTSDlibSetup *m_gui;
 };
 
 #endif
