@@ -46,11 +46,10 @@
 #define _SBDPROC_H_
 
 // Qt includes.
-#include <qobject.h>
-#include <qstringlist.h>
-#include <qthread.h>
-#include <qvaluestack.h>
-#include <qevent.h>
+#include <QtCore/QObject>
+#include <QtCore/QThread>
+#include <QtCore/QEvent>
+#include <QtCore/QStack>
 
 // KTTS includes.
 #include "filterproc.h"
@@ -60,7 +59,7 @@ class KConfig;
 class QDomElement;
 class QDomNode;
 
-class SbdThread: public QObject, public QThread
+class SbdThread: public QThread
 {
     Q_OBJECT
 
@@ -68,7 +67,7 @@ class SbdThread: public QObject, public QThread
         /**
          * Constructor.
          */
-        SbdThread( QObject *parent = 0, const char *name = 0);
+        SbdThread( QObject *parent = 0);
 
         /**
          * Destructor.
@@ -215,11 +214,11 @@ class SbdThread: public QObject, public QThread
         QString parsePlainText( const QString& inputText, const QString& re );
 
         // Context stacks.
-        QValueStack<SpeakElem> m_speakStack;
-        QValueStack<VoiceElem> m_voiceStack;
-        QValueStack<ProsodyElem> m_prosodyStack;
-        QValueStack<EmphasisElem> m_emphasisStack;
-        QValueStack<PSElem> m_psStack;
+        QStack<SpeakElem> m_speakStack;
+        QStack<VoiceElem> m_voiceStack;
+        QStack<ProsodyElem> m_prosodyStack;
+        QStack<EmphasisElem> m_emphasisStack;
+        QStack<PSElem> m_psStack;
 
         // The text being processed.
         QString m_text;
@@ -245,7 +244,7 @@ class SbdProc : virtual public KttsFilterProc
         /**
          * Constructor.
          */
-        SbdProc( QObject *parent, const char *name, const QStringList &args = QStringList() );
+        explicit SbdProc( QObject *parent, const QStringList &args = QStringList() );
 
         /**
          * Destructor.
@@ -291,7 +290,7 @@ class SbdProc : virtual public KttsFilterProc
          * @param appId             The DCOP appId of the application that queued the text.
          *                          Also useful for hints about how to do the filtering.
          */
-        virtual QString convert( const QString& inputText, TalkerCode* talkerCode, const QCString& appId );
+        virtual QString convert( const QString& inputText, TalkerCode* talkerCode, const QString& appId );
 
         /**
          * Convert input.  Runs asynchronously.
@@ -307,7 +306,7 @@ class SbdProc : virtual public KttsFilterProc
          * program may then call @ref getOutput to retrieve converted text.  Calling
          * program must call @ref ackFinished to acknowledge the conversion.
          */
-        virtual bool asyncConvert( const QString& inputText, TalkerCode* talkerCode, const QCString& appId );
+        virtual bool asyncConvert( const QString& inputText, TalkerCode* talkerCode, const QString& appId );
 
         /**
          * Waits for a previous call to asyncConvert to finish.
