@@ -22,14 +22,14 @@
  ******************************************************************************/
 
 // Qt includes.
-#include <qdom.h>
-#include <qfile.h>
-#include <qlistview.h>
+#include <QtXml/QDomDocument>
+#include <QtCore/QFile>
 
 // KDE includes.
 #include <kdebug.h>
 #include <klocale.h>
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
 
@@ -44,8 +44,8 @@
 /**
  * Constructor.
  */
-StringReplacerProc::StringReplacerProc( QObject *parent, const char *name, const QStringList& ) :
-    KttsFilterProc(parent, name)
+StringReplacerProc::StringReplacerProc( QObject *parent, const QStringList& ) :
+    KttsFilterProc(parent)
 {
 }
 
@@ -55,7 +55,6 @@ StringReplacerProc::StringReplacerProc( QObject *parent, const char *name, const
 /*virtual*/ StringReplacerProc::~StringReplacerProc()
 {
     m_matchList.clear();
-    m_caseList.clear();
     m_substList.clear();
 }
 
@@ -68,18 +67,18 @@ StringReplacerProc::StringReplacerProc( QObject *parent, const char *name, const
  * Note: The parameters are for reading from kttsdrc file.  Plugins may wish to maintain
  * separate configuration files of their own.
  */
-bool StringReplacerProc::init(KConfig* config, const QString& configGroup){
-    // kdDebug() << "StringReplacerProc::init: Running" << endl;
+bool StringReplacerProc::init(KConfig* c, const QString& configGroup){
+    // kDebug() << "StringReplacerProc::init: Running";
     QString wordsFilename =
         KGlobal::dirs()->saveLocation( "data" ,"kttsd/stringreplacer/", false );
     if ( wordsFilename.isEmpty() ) return false;
     wordsFilename += configGroup;
-    config->setGroup( configGroup );
-    wordsFilename = config->readEntry( "WordListFile", wordsFilename );
+    KConfigGroup config( c, configGroup );
+    wordsFilename = config.readEntry( "WordListFile", wordsFilename );
 
     // Open existing word list.
     QFile file( wordsFilename );
-    if ( !file.open( IO_ReadOnly ) )
+    if ( !file.open( QIODevice::ReadOnly ) )
         return false;
     QDomDocument doc( "" );
     if ( !doc.setContent( &file ) ) {
@@ -90,7 +89,6 @@ bool StringReplacerProc::init(KConfig* config, const QString& configGroup){
 
     // Clear list.
     m_matchList.clear();
-    m_caseList.clear();
     m_substList.clear();
 
     // Name setting.
@@ -102,10 +100,10 @@ bool StringReplacerProc::init(KConfig* config, const QString& configGroup){
     // or multiple elements.
     m_languageCodeList.clear();
     QDomNodeList languageList = doc.elementsByTagName( "language-code" );
-    for ( uint ndx=0; ndx < languageList.count(); ++ndx )
+    for ( int ndx=0; ndx < languageList.count(); ++ndx )
     {
         QDomNode languageNode = languageList.item( ndx );
-        m_languageCodeList += QStringList::split(',', languageNode.toElement().text(), false);
+        m_languageCodeList += languageNode.toElement().text().split( ',', QString::SkipEmptyParts);
     }
 
     // AppId.  Apply this filter only if DCOP appId of application that queued
@@ -113,10 +111,10 @@ bool StringReplacerProc::init(KConfig* config, const QString& configGroup){
     // or multiple elements.
     m_appIdList.clear();
     QDomNodeList appIdList = doc.elementsByTagName( "appid" );
-    for ( uint ndx=0; ndx < appIdList.count(); ++ndx )
+    for ( int ndx=0; ndx < appIdList.count(); ++ndx )
     {
         QDomNode appIdNode = appIdList.item( ndx );
-        m_appIdList += QStringList::split(',', appIdNode.toElement().text(), false);
+        m_appIdList += appIdNode.toElement().text().split( ',', QString::SkipEmptyParts);
     }
 
     // Word list.
@@ -142,7 +140,7 @@ bool StringReplacerProc::init(KConfig* config, const QString& configGroup){
         }
         // Build Regular Expression for each word's match string.
         QRegExp rx;
-        rx.setCaseSensitive(matchCase == "Yes");
+        rx.setCaseSensitivity(matchCase == "Yes"?Qt::CaseInsensitive:Qt::CaseSensitive);
         if ( wordType == "Word" )
         {
                 // TODO: Does \b honor strange non-Latin1 encodings?
@@ -171,21 +169,22 @@ bool StringReplacerProc::init(KConfig* config, const QString& configGroup){
  * @param appId             The DCOP appId of the application that queued the text.
  *                          Also useful for hints about how to do the filtering.
  */
-/*virtual*/ QString StringReplacerProc::convert(const QString& inputText, TalkerCode* talkerCode, const QCString& appId)
+/*virtual*/ QString StringReplacerProc::convert(const QString& inputText, TalkerCode* talkerCode,
+    const QString& appId)
 {
     m_wasModified = false;
     // If language doesn't match, return input unmolested.
     if ( !m_languageCodeList.isEmpty() )
     {
         QString languageCode = talkerCode->languageCode();
-        // kdDebug() << "StringReplacerProc::convert: converting " << inputText << 
+        // kDebug() << "StringReplacerProc::convert: converting " << inputText << 
         //    " if language code " << languageCode << " matches " << m_languageCodeList << endl;
         if ( !m_languageCodeList.contains( languageCode ) )
         {
             if ( !talkerCode->countryCode().isEmpty() )
             {
                 languageCode += '_' + talkerCode->countryCode();
-                // kdDebug() << "StringReplacerProc::convert: converting " << inputText << 
+                // kDebug() << "StringReplacerProc::convert: converting " << inputText << 
                 //    " if language code " << languageCode << " matches " << m_languageCodeList << endl;
                 if ( !m_languageCodeList.contains( languageCode ) ) return inputText;
             } else return inputText;
@@ -194,11 +193,11 @@ bool StringReplacerProc::init(KConfig* config, const QString& configGroup){
     // If appId doesn't match, return input unmolested.
     if ( !m_appIdList.isEmpty() )
     {
-        // kdDebug() << "StringReplacerProc::convert: converting " << inputText << " if appId "
+        // kDebug() << "StringReplacerProc::convert: converting " << inputText << " if appId "
         //     << appId << " matches " << m_appIdList << endl;
         bool found = false;
         QString appIdStr = appId;
-        for ( uint ndx=0; ndx < m_appIdList.count(); ++ndx )
+        for ( int ndx=0; ndx < m_appIdList.count(); ++ndx )
         {
             if ( appIdStr.contains(m_appIdList[ndx]) )
             {
@@ -208,7 +207,7 @@ bool StringReplacerProc::init(KConfig* config, const QString& configGroup){
         }
         if ( !found )
         {
-            // kdDebug() << "StringReplacerProc::convert: appId not found" << endl;
+            // kDebug() << "StringReplacerProc::convert: appId not found";
             return inputText;
         }
     }
@@ -216,7 +215,7 @@ bool StringReplacerProc::init(KConfig* config, const QString& configGroup){
     const int listCount = m_matchList.count();
     for ( int index = 0; index < listCount; ++index )
     {
-        //kdDebug() << "newtext = " << newText << " matching " << m_matchList[index].pattern() << " replacing with " << m_substList[index] << endl;
+        //kDebug() << "newtext = " << newText << " matching " << m_matchList[index].pattern() << " replacing with " << m_substList[index];
         newText.replace( m_matchList[index], m_substList[index] );
     }
     m_wasModified = true;
