@@ -26,17 +26,16 @@
 #define _FILTERPROC_H_
 
 // Qt includes.
-#include <qobject.h>
-#include <qstringlist.h>
+#include <QtCore/QObject>
 
 // KDE includes.
 #include <kdemacros.h>
-#include "kdeexportfix.h"
 
 class TalkerCode;
 class KConfig;
+class KConfigGroup;
 
-class KDE_EXPORT KttsFilterProc : virtual public QObject
+class KDE_EXPORT KttsFilterProc : public QObject
 {
     Q_OBJECT
 
@@ -51,7 +50,7 @@ public:
     /**
      * Constructor.
      */
-    KttsFilterProc( QObject *parent, const char *name );
+    KttsFilterProc( QObject *parent );
 
     /**
      * Destructor.
@@ -67,7 +66,7 @@ public:
      * Note: The parameters are for reading from kttsdrc file.  Plugins may wish to maintain
      * separate configuration files of their own.
      */
-    virtual bool init(KConfig *config, const QString &configGroup);
+    virtual bool init(const KConfigGroup &config);
 
     /**
      * Returns True if this filter is a Sentence Boundary Detector.
@@ -97,7 +96,7 @@ public:
      * @param appId             The DCOP appId of the application that queued the text.
      *                          Also useful for hints about how to do the filtering.
      */
-    virtual QString convert(const QString& inputText, TalkerCode* talkerCode, const QCString& appId);
+    virtual QString convert(const QString& inputText, TalkerCode* talkerCode, const QString& appId);
 
     /**
      * Convert input.  Runs asynchronously.
@@ -113,7 +112,7 @@ public:
      * program may then call @ref getOutput to retrieve converted text.  Calling
      * program must call @ref ackFinished to acknowledge the conversion.
      */
-    virtual bool asyncConvert(const QString& inputText, TalkerCode* talkerCode, const QCString& appId);
+    virtual bool asyncConvert(const QString& inputText, TalkerCode* talkerCode, const QString& appId);
 
     /**
      * Waits for a previous call to asyncConvert to finish.
